import { FastifyRequest, FastifyReply } from 'fastify';
import { User } from '../../models/User';

interface AuthenticatedRequest extends FastifyRequest {
  user: {
    id: number;
    email: string;
    role: string;
  };
}


export const getProfileHandler = async (
  request: AuthenticatedRequest,
  reply: FastifyReply
) => {
  try {
    const user = await User.findByPk((request as AuthenticatedRequest).user.id, {
      attributes: ['id', 'name', 'email', 'role', 'createdAt', 'updatedAt'],
    });

    if (!user) {
      return reply.status(404).send({ error: 'User not found' });
    }

    return reply.send({ user });
  } catch (err) {
    console.error(err);
    return reply.status(500).send({ error: 'Failed to fetch profile' });
  }
};
