// src/routes/auth/google.ts
import { FastifyInstance, FastifyRequest } from 'fastify';
import { OAuth2Client } from 'google-auth-library';
import { google } from 'googleapis';
import dotenv from 'dotenv';

dotenv.config();

interface GoogleCallbackQuery {
  code: string;
}

export async function googleAuthRoutes(fastify: FastifyInstance) {
  const client = new OAuth2Client(
    process.env.GOOGLE_CLIENT_ID!,
    process.env.GOOGLE_CLIENT_SECRET!,
    process.env.GOOGLE_REDIRECT_URI!
  );

  fastify.get('/auth/google', async (_request, reply) => {
    const url = client.generateAuthUrl({
      access_type: 'offline',
      scope: ['profile', 'email'],
      prompt: 'consent',
    });

    reply.redirect(url);
  });

  fastify.get('/auth/google/callback', async (
    request: FastifyRequest<{ Querystring: GoogleCallbackQuery }>,
    reply
  ) => {
    const code = request.query.code;

    const { tokens } = await client.getToken(code);
    client.setCredentials(tokens);

    const oauth2 = google.oauth2({
      auth: client,
      version: 'v2',
    });

    const userInfoResponse = await oauth2.userinfo.get();
    const userInfo = userInfoResponse.data;

    const query = new URLSearchParams({
      name: userInfo.name ?? '',
      email: userInfo.email ?? '',
    });

    reply.redirect(`http://localhost:3000/profile?${query.toString()}`);
  });
}
